from jinja2 import Template


def get_parameters(template):
    params = template.get('Parameters')
    if not params:
        params = template.get('parameters')
    if not params:
        params = []
    return params


def get_resources(template):
    resources = template.get('Resources')
    if not resources:
        resources = template.get('resources')
    if not resources:
        resources = []
    return resources


def get_outputs(template):
    outputs = template.get('Outputs')
    if not outputs:
        outputs = template.get('outputs')
    if not outputs:
        outputs = []
    return outputs


def get_description(template):
    description = template.get("Description")
    if not description:
        description = template.get('description')
    if not description:
        description = "No Template description set"
    return description


TEMPLATE = """# {{ name }}
# Description
{{ description }}

## Parameters
The list of parameters for this template:
{% for parameter in parameters %}
### {{ parameter }} 
Type: {{ parameters[parameter].Type }} {% if parameters[parameter].Default %}
Default: {{ parameters[parameter].Default}}{% endif %} {% if parameters[parameter].Description %}
Description: {{ parameters[parameter].Description}}{% endif %} {% endfor %}

## Resources
The list of resources this template creates:
{% for resource in resources %}
### {{ resource }} 
Type: {{ resources[resource].Type }} {% if resources[resource].Description %}
Description: {{ resources[resource].Description}}{% endif %} {% endfor %}

## Outputs
The list of outputs this template exposes:
{% for output in outputs %}
### {{ output }} 
{% if outputs[output].Description %}Description: {{ outputs[output].Description}}{% endif %}{% if outputs[output].Export %} 
Export name: {{ outputs[output].Export.Name }}{% endif %}  
{% endfor %}
"""


def generate(template, name):
    description = get_description(template)
    parameters = get_parameters(template)
    resources = get_resources(template)
    outputs = get_outputs(template)

    return Template(TEMPLATE).render(
        name=name,
        description=description,
        parameters=parameters,
        resources=resources,
        outputs=outputs,
    )



import click
import json
from cfn_flip import to_json

from . import core


@click.command()
@click.argument('f', type=click.File())
def generate(f):
    extension = f.name.split(".").pop()
    if extension in ["yaml", "yml"]:
        j = to_json(f)
    elif extension in ["json"]:
        j = f
    else:
        raise Exception("{}: not a valid file extension".format(extension))
    template = json.loads(j)
    result = core.generate(template, ".".join(f.name.split(".")[0:-1]))
    click.echo(result)


if __name__ == "__main__":
    generate()



from . import core
import json
from cfn_tools import load_yaml


def generate_from_json(template_content, name):
    result = core.generate(json.loads(template_content), name)
    return result


def generate_from_yaml(template_content, name):
    result = core.generate(load_yaml(template_content), name)
    return result



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

with open("cloudformation_docs/requirements.txt", "r") as fh:
    requirements = fh.read().split("\n")

setuptools.setup(
    name="cloudformation-docs",
    version="0.3.2",
    author="Eamonn Faherty",
    author_email="packages@designandsolve.co.uk",
    description="Generate docs from cloudformation templates",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/eamonnfaherty/cloudformation-doc-generator",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': [
            'cfn-docs = cloudformation_docs.cli:generate'
        ]},
    install_requires=requirements,
)
